@@ -18,8 +18,8 @@
  */
 package org.apache.cxf.spring.boot.jaxrs;
 
-import javax.ws.rs.GET;
-import javax.ws.rs.Path;
+import jakarta.ws.rs.GET;
+import jakarta.ws.rs.Path;
 
 @Path("/sample")
 public class SampleJaxRSResource {
