@@ -24,9 +24,6 @@ import java.nio.charset.StandardCharsets;
 import java.security.cert.X509Certificate;
 import java.util.List;
 
-import javax.ws.rs.core.MediaType;
-import javax.ws.rs.core.Response;
-import javax.xml.bind.JAXBElement;
 import javax.xml.transform.dom.DOMSource;
 
 import org.w3c.dom.Document;
@@ -34,6 +31,9 @@ import org.w3c.dom.Element;
 
 import com.fasterxml.jackson.databind.ObjectMapper;
 
+import jakarta.ws.rs.core.MediaType;
+import jakarta.ws.rs.core.Response;
+import jakarta.xml.bind.JAXBElement;
 import org.apache.cxf.common.util.Base64Utility;
 import org.apache.cxf.common.util.CompressionUtils;
 import org.apache.cxf.jaxrs.client.WebClient;
@@ -313,7 +313,7 @@ public class STSRESTTest extends AbstractBusClientServerTestBase {
         assertEquals(1, claims.size());
         Claim claim = claims.get(0);
         String role = "http://schemas.xmlsoap.org/ws/2005/05/identity/claims/role";
-        assertNotEquals(role, claim.getClaimType().toString());
+        assertNotEquals(role, claim.getClaimType());
 
         // Now get another token specifying the role
         client.query("claim", role);
@@ -325,7 +325,7 @@ public class STSRESTTest extends AbstractBusClientServerTestBase {
         claims = SAMLUtils.getClaims(assertion);
         assertEquals(1, claims.size());
         claim = claims.get(0);
-        assertEquals(role, claim.getClaimType().toString());
+        assertEquals(role, claim.getClaimType());
         assertEquals("ordinary-user", claim.getValues().get(0));
     }
 
