@@ -19,10 +19,9 @@
 
 package org.apache.cxf.systest.jaxrs;
 
-
-import javax.ws.rs.GET;
-import javax.ws.rs.Path;
-import javax.ws.rs.PathParam;
+import jakarta.ws.rs.GET;
+import jakarta.ws.rs.Path;
+import jakarta.ws.rs.PathParam;
 
 @Path("/bookstore")
 public class BookStoreSubObject {
